from django.urls import path, include
from . import views
  
app_name="portal"

urlpatterns = [
    #stela Home
    path('i18n/', include('django.conf.urls.i18n')),
    path('auth/login/', views.login, name="login"),
    path('auth/register/', views.account_register, name="register"),
    path('auth/logout/', views.logout, name="logout"),
    
 ]   


from django.shortcuts import render
from django.contrib.auth import logout
from django.shortcuts import redirect, render
from stela_control.forms import RegistrationForm, UserLoginForm
# Create your views here.
def login(request):
    form=UserLoginForm()
    context = {
       'form': form
    }
    return render(request, 'home/auth/login/index.html', context)

def account_register(request):
    form=RegistrationForm()
    context = {
        'form': form
    }
    return render(request, 'home/auth/registration/index.html', context)

def logout(request):
    logout(request)
    return redirect('/auth/login/')